
.. _geoclaw_examples_multi-layer_bowl-radial:

Tsunami in a parabolic bowl shaped ocean
========================================

Waves in a parabolic bowl of two layers of water generated by a Gaussian 
hump of water at the origin.  The solution should remain circularly symmetric.

To create the topo file before running the code::

    make topo


In this code, :math:`x` and :math:`y` are in meters (coordinate_system=1 
in `setrun.py`).

Refinement is allowed only in the upper right quadrant, using the regions
specified in `setrun.py`.

Gauges are placed near the shore along the x-axis and along the diagonal.
Ideally these gauges would show identical results.

